SpDustPol — pysm v3.0.0

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.0.0 »
- pysm Documentation »
- SpDustPol

# SpDustPol

class `pysm.` `SpDustPol`(map_I, freq_ref_I, emissivity, freq_peak, freq_ref_peak, pol_frac, angle_Q, angle_U, nside, unit_I=None, map_dist=None)

  Bases: `pysm.SpDust`

  SpDust2 model with Polarized emission

  Methods Summary

  `get_emission`(self, freqs[, weights]) | This function evaluates the component model at a either a single frequency, an array of frequencies, or over a bandpass.

  Methods Documentation

  `get_emission`(self, freqs:Unit("GHz"), weights=None)

    This function evaluates the component model at a either a single frequency, an array of frequencies, or over a bandpass.

    Parameters
      freqs: float

        Frequency at which the model should be evaluated, assumed to be given in GHz.

    Returns
      ndarray

        Set of maps at the given frequency or frequencies. This will have shape (nfreq, 3, npix).